@@ -87,7 +87,7 @@
 #define MSG_ANON_CANT_DELETE "Anonyme Benutzer drfen keine Dateien lschen."
 #define MSG_ANON_CANT_OVERWRITE "Anonyme Benutzer drfen keine existierenden Dateien berschreiben."
 #define MSG_DELE_FAILED "Konnte %s nicht lschen."
-#define MSG_DELE_SUCCESS "%s gelscht."
+#define MSG_DELE_SUCCESS "%s%s%s%s gelscht."
 #define MSG_DELE_TOTAL_FAILURE "Keine Datei gelscht."
 #define MSG_LOAD_TOO_HIGH \
     "Zum Zeitpunkt der Verbindung war die Last %3.2f. Wir erlauben keinen Download\n" \
