@@ -87,7 +87,7 @@
 #define MSG_ANON_CANT_DELETE "Anonymous felhasznlk nem trlhetnek"
 #define MSG_ANON_CANT_OVERWRITE "Anonymous felhasznlk taln nem rhatnak fell meglvo fjlokat"
 #define MSG_DELE_FAILED "Nem lehet trlni %s"
-#define MSG_DELE_SUCCESS "%s trlve"
+#define MSG_DELE_SUCCESS "%s%s%s%s trlve"
 #define MSG_DELE_TOTAL_FAILURE "Egyetlen fjl sem lett trlve"
 #define MSG_LOAD_TOO_HIGH \
     "A terhels %3.2f mikor csatlakoztl. A letlts le van tiltva\n" \
