@@ -87,7 +87,7 @@
 #define MSG_ANON_CANT_DELETE "Misafir kullanc dosyalar silimez"
 #define MSG_ANON_CANT_OVERWRITE "Misafir kullanc varolan dosya zerine yazamaz"
 #define MSG_DELE_FAILED "%s silinemiyor"
-#define MSG_DELE_SUCCESS "%s silindi"
+#define MSG_DELE_SUCCESS "%s%s%s%s silindi"
 #define MSG_DELE_TOTAL_FAILURE "Silinen dosya yok"
 #define MSG_LOAD_TOO_HIGH \
     "Balantnzdan sonra yk %3.2f . Ar yklenme esnasnda misafir ndirmelere izin veremiyoruz.\n" \
