@@ -211,20 +211,20 @@ static void newenv_str(const char * const var, const char * const str)
 static ssize_t safe_read(const int fd, void * const buf_, size_t maxlen)
 {
     unsigned char *buf = (unsigned char *) buf_;
-    ssize_t readen;
+    ssize_t readnb;
     
     do {
-        while ((readen = read(fd, buf, maxlen)) < (ssize_t) 0 && 
+        while ((readnb = read(fd, buf, maxlen)) < (ssize_t) 0 && 
                errno == EINTR);
-        if (readen < (ssize_t) 0 || readen > (ssize_t) maxlen) {
-            return readen;
+        if (readnb < (ssize_t) 0 || readnb > (ssize_t) maxlen) {
+            return readnb;
         }
-        if (readen == (ssize_t) 0) {
+        if (readnb == (ssize_t) 0) {
             ret:
             return (ssize_t) (buf - (unsigned char *) buf_);
         }
-        maxlen -= readen;
-        buf += readen;
+        maxlen -= readnb;
+        buf += readnb;
     } while (maxlen > (ssize_t) 0);
     goto ret;
 }
@@ -310,19 +310,19 @@ static void callback_client_end(const char *str)
 
 static void process(const int clientfd)
 {
-    ssize_t readen;
+    ssize_t readnb;
     char *linepnt;
     char *crpoint;
     pid_t pid;
     int pfds[2];
     char line[4096];
     
-    while ((readen = read(clientfd, line, sizeof line - 1U)) < (ssize_t) 0 &&
+    while ((readnb = read(clientfd, line, sizeof line - 1U)) < (ssize_t) 0 &&
            (errno == EINTR || errno == EIO));
-    if (readen <= (ssize_t) 0) {
+    if (readnb <= (ssize_t) 0) {
         return;
     }
-    line[readen] = 0;
+    line[readnb] = 0;
     if (pipe(pfds) != 0) {
         return;
     }
@@ -334,9 +334,9 @@ static void process(const int clientfd)
     }    
     if (pid != (pid_t) 0) {
         close(pfds[1]);         /* close the output side of the pipe */
-        if ((readen = safe_read(pfds[0], line, 
+        if ((readnb = safe_read(pfds[0], line, 
                                 sizeof line - 1U)) > (ssize_t) 0) {
-            (void) safe_write(clientfd, line, readen);
+            (void) safe_write(clientfd, line, readnb);
         }
 #ifdef HAVE_WAITPID
         (void) waitpid(pid, NULL, 0);
